@@ -158,8 +158,12 @@ class TestingApp(RequestHandler):
     def redirect(self, request):
         "Perform a redirect to ``target``"
         target = request.params.get('target', '/')
+        status = request.params.get('status', '303 See Other')
+        if len(status) == 3:
+            status = '%s Redirect' % status.decode('latin-1')
+
         headers = [('Location', target)]
-        return Response(status='303 See Other', headers=headers)
+        return Response(status=status, headers=headers)
 
     def multi_redirect(self, request):
         "Performs a redirect chain based on ``redirect_codes``"
@@ -327,6 +331,7 @@ def _parse_header(line):
         pdict[name] = value
     return key, pdict
 
+
 # TODO: make the following conditional as soon as we know a version
 #       which does not require this fix.
 #       See https://github.com/facebook/tornado/issues/868
